merged_df3 = as.data.frame(merged_df3)
corr_plotdf = corr_data_extract(merged_df3
                                , gene = gene
                                , drug = drug
                                , extract_scaled_cols = F)
colnames(corr_plotdf)

#================
# stability
#================
corr_ps_colnames = c("DUET"
                     , "FoldX"
                     , "DeepDDG"
                     , "Dynamut2"
                     , "MAF"             
                     , "Log(OR)"       
                     , "-Log(P)"
                     #, "ligand_distance"
                     , "dst_mode"
                     , drug)

corr_ps_colnames%in%colnames(corr_plotdf)
corr_df_ps = corr_plotdf[, corr_ps_colnames]

color_coln = which(colnames(corr_df_ps) == "dst_mode")
end = which(colnames(corr_df_ps) == drug)
ncol_omit = 2
corr_end = end-ncol_omit

#------------------------
# Output: stability corrP
#------------------------
corr_psP =  paste0(outdir_images
                          ,tolower(gene)
                          ,"_corr_stability.svg" )

cat("Corr plot stability with coloured dots:", corr_psP)
svg(corr_psP, width = 15, height = 15)

my_corr_pairs(corr_data_all = corr_df_ps
  , corr_cols = colnames(corr_df_ps[1:corr_end])
  , corr_method = "spearman" # other options: "pearson" or "kendall"
  , colour_categ_col = colnames(corr_df_ps[color_coln]) #"dst_mode"
  , categ_colour =  c("red", "blue")
  , density_show = F
  , hist_col = "coral4"
  , dot_size = 1.6
  , ats = 1.5
  , corr_lab_size = 3
  , corr_value_size = 1)

dev.off()
#####################################################
#DistCutOff = 10
#LigDist_colname  # = "ligand_distance" # from globals 
#ppi2Dist_colname  = "interface_dist"
#naDist_colname    = "TBC"
#####################################################

#================
# ligand affinity
#================
corr_lig_colnames = c("mCSM-lig"       
                      , "MAF"             
                      , "Log(OR)"       
                      , "-Log(P)"
                      , "Lig-Dist"
                      , "dst_mode"
                      , drug)

corr_lig_colnames%in%colnames(corr_plotdf)
corr_df_lig = corr_plotdf[, corr_lig_colnames]
corr_df_lig = corr_df_lig[corr_df_lig["Lig-Dist"]<DistCutOff,]

color_coln = which(colnames(corr_df_lig) == "dst_mode")
end = which(colnames(corr_df_lig) == drug)
ncol_omit = 3  #omit dist col
corr_end = end-ncol_omit

#------------------------
# Output: ligand corrP
#------------------------
corr_ligP =  paste0(outdir_images
                   ,tolower(gene)
                   ,"_corr_lig.svg" )

cat("Corr plot affinity with coloured dots:", corr_ligP)
svg(corr_ligP, width = 10, height = 10)

my_corr_pairs(corr_data_all = corr_df_lig
              , corr_cols = colnames(corr_df_lig[1:corr_end])
              , corr_method = "spearman" # other options: "pearson" or "kendall"
              , colour_categ_col = colnames(corr_df_lig[color_coln]) #"dst_mode"
              , categ_colour =  c("red", "blue")
              , density_show = F
              , hist_col = "coral4"
              , dot_size = 2
              , ats = 1.5
              , corr_lab_size =3
              , corr_value_size = 1)
dev.off()
####################################################
#================
# ppi2 affinity
#================
corr_ppi2_colnames = c("mCSM-PPI2"
                       , "MAF"             
                       , "Log(OR)"       
                       , "-Log(P)"
                       , "PPI-Dist"  # "interface_dist"
                       , "dst_mode"
                       , drug)

corr_ppi2_colnames%in%colnames(corr_plotdf)
corr_df_ppi2 = corr_plotdf[, corr_ppi2_colnames]
corr_df_ppi2 = corr_df_ppi2[corr_df_ppi2["PPI-Dist"]<DistCutOff,]

color_coln = which(colnames(corr_df_ppi2) == "dst_mode")
end = which(colnames(corr_df_ppi2) == drug)
ncol_omit = 3 #omit dist col
corr_end = end-ncol_omit

#------------------------
# Output: ppi2 corrP
#------------------------
corr_ppi2P =  paste0(outdir_images
                    ,tolower(gene)
                    ,"_corr_ppi2.svg" )

cat("Corr plot ppi2 with coloured dots:", corr_ppi2P)
svg(corr_ppi2P, width = 10, height = 10)

my_corr_pairs(corr_data_all = corr_df_ppi2
              , corr_cols = colnames(corr_df_ppi2[1:corr_end])
              , corr_method = "spearman" # other options: "pearson" or "kendall"
              , colour_categ_col = colnames(corr_df_ppi2[color_coln]) #"dst_mode"
              , categ_colour =  c("red", "blue")
              , density_show = F
              , hist_col = "coral4"
              , dot_size = 2
              , ats = 1.5
              , corr_lab_size = 3
              , corr_value_size = 1)

dev.off()

# FIXME: ADD distance
#==================
# mCSSM-NA affinity
#==================




####################################################
# CONSERVATION
corr_conservation_cols = c("ConSurf"
                           , "SNAP2"
                           , "PROVEAN"
                           , "MAF"             
                           , "Log(OR)"       
                           , "-Log(P)"
                           , "dst_mode"
                           , drug)

####################################################
colnames(corr_plotdf)
corr_conservation_cols%in%colnames(corr_plotdf)

corr_df_cons = corr_plotdf[, corr_conservation_cols]

color_coln = which(colnames(corr_df_cons) == "dst_mode")
end = which(colnames(corr_df_cons) == drug)
ncol_omit = 2 
corr_end = end-ncol_omit

#---------------------------
# Output: Conservation corrP
#----------------------------
corr_consP =  paste0(outdir_images
                     ,tolower(gene)
                     ,"_corr_ppi2.svg" )

cat("Corr plot conservation coloured dots:", corr_consP)
svg(corr_consP, width = 10, height = 10)

my_corr_pairs(corr_data_all = corr_df_cons
              , corr_cols = colnames(corr_df_cons[1:corr_end])
              , corr_method = "spearman" # other options: "pearson" or "kendall"
              , colour_categ_col = colnames(corr_df_cons[color_coln]) #"dst_mode"
              , categ_colour =  c("red", "blue")
              , density_show = F
              , hist_col = "coral4"
              , dot_size = 2
              , ats = 1.5
              , corr_lab_size = 3
              , corr_value_size = 1)

dev.off()
